ActiveUserInsertDto class

Insert DTO for ActiveUser.

Auto-increment/DB-generated fields are omitted by default.

Constructors

ActiveUserInsertDto({String? email, String? name, Map<String, Object?>? settings})
const

Properties

email String?
final
hashCode int
The hash code for this object.
no setterinherited
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings Map<String, Object?>?
final

Methods

copyWith({Object? email = _copyWithSentinel, Object? name = _copyWithSentinel, Object? settings = _copyWithSentinel}) ActiveUserInsertDto
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this DTO to a map suitable for database insertion.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited