DerivedForFactoryUpdateDto class

Update DTO for DerivedForFactory.

All fields are optional; only provided entries are used in SET clauses.

Constructors

DerivedForFactoryUpdateDto({bool? layerTwoFlag, Map<String, Object?>? layerOneNotes, int? id, String? baseName})
const

Properties

baseName String?
final
hashCode int
The hash code for this object.
no setterinherited
id int?
final
layerOneNotes Map<String, Object?>?
final
layerTwoFlag bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? layerTwoFlag = _copyWithSentinel, Object? layerOneNotes = _copyWithSentinel, Object? id = _copyWithSentinel, Object? baseName = _copyWithSentinel}) DerivedForFactoryUpdateDto
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this DTO to a map suitable for database updates.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited