TagOrmExtension extension

on

Methods

copyWith({Object? id = _copyWithSentinel, Object? label = _copyWithSentinel}) Tag

Available on Tag, provided by the TagOrmExtension extension

toMap({ValueCodecRegistry? registry}) Map<String, Object?>

Available on Tag, provided by the TagOrmExtension extension

Converts this model to a column/value map.
toTracked() $Tag

Available on Tag, provided by the TagOrmExtension extension

Converts this immutable model to a tracked ORM-managed model. The tracked model supports attribute tracking, change detection, and persistence operations like save() and touch().

Static Properties

trackedType Type

Available on Tag, provided by the TagOrmExtension extension

The Type of the generated ORM-managed model class. Use this when you need to specify the tracked model type explicitly, for example in generic type parameters.
no setter

Static Methods

fromMap(Map<String, Object?> data, {ValueCodecRegistry? registry}) Tag

Available on Tag, provided by the TagOrmExtension extension

Builds a model from a column/value map.