UserProfileInsertDto class

Insert DTO for UserProfile.

Auto-increment/DB-generated fields are omitted by default.

Constructors

UserProfileInsertDto({int? userId, String? bio})
const

Properties

bio String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int?
final

Methods

copyWith({Object? userId = _copyWithSentinel, Object? bio = _copyWithSentinel}) UserProfileInsertDto
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts this DTO to a map suitable for database insertion.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited