CastSampleOrmExtension extension
- on
Methods
-
copyWith(
{Object? id = _copyWithSentinel, Object? name = _copyWithSentinel, Object? isActive = _copyWithSentinel, Object? visits = _copyWithSentinel, Object? ratio = _copyWithSentinel, Object? startedOn = _copyWithSentinel, Object? updatedAt = _copyWithSentinel, Object? amount = _copyWithSentinel, Object? status = _copyWithSentinel, Object? secret = _copyWithSentinel}) → CastSample -
Available on CastSample, provided by the CastSampleOrmExtension extension
-
toMap(
{ValueCodecRegistry? registry}) → Map< String, Object?> -
Available on CastSample, provided by the CastSampleOrmExtension extension
Converts this model to a column/value map. -
toTracked(
) → $CastSample -
Available on CastSample, provided by the CastSampleOrmExtension extension
Converts this immutable model to a tracked ORM-managed model. The tracked model supports attribute tracking, change detection, and persistence operations like save() and touch().
Static Properties
- trackedType → Type
-
Available on CastSample, provided by the CastSampleOrmExtension extension
The Type of the generated ORM-managed model class. Use this when you need to specify the tracked model type explicitly, for example in generic type parameters.no setter
Static Methods
-
fromMap(
Map< String, Object?> data, {ValueCodecRegistry? registry}) → CastSample -
Available on CastSample, provided by the CastSampleOrmExtension extension
Builds a model from a column/value map.