CommentOrmExtension extension
- on
Methods
-
copyWith(
{Object? id = _copyWithSentinel, Object? body = _copyWithSentinel, Object? postId = _copyWithSentinel}) → Comment -
Available on Comment, provided by the CommentOrmExtension extension
-
toMap(
{ValueCodecRegistry? registry}) → Map< String, Object?> -
Available on Comment, provided by the CommentOrmExtension extension
Converts this model to a column/value map. -
toTracked(
) → $Comment -
Available on Comment, provided by the CommentOrmExtension extension
Converts this immutable model to a tracked ORM-managed model. The tracked model supports attribute tracking, change detection, and persistence operations like save() and touch().
Static Properties
- trackedType → Type
-
Available on Comment, provided by the CommentOrmExtension extension
The Type of the generated ORM-managed model class. Use this when you need to specify the tracked model type explicitly, for example in generic type parameters.no setter