ImageSeeder class
Seeder for Image model in driver tests
Constructors
- ImageSeeder(OrmConnection connection)
Properties
- connection → OrmConnection
-
finalinherited
- eventBus ↔ EventBus?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attachEventBus(
EventBus bus) → void -
Attach an event bus so nested seeders share the same emitter.
inherited
-
call(
List< DatabaseSeeder Function(OrmConnection)> factories) → Future<void> -
Call other seeders
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
) → Future< void> - Run the seeder
-
seed<
TModel extends Model< (TModel> >List< Map< records) → Future<String, dynamic> >List< TModel> > -
Seed multiple records for a given model type
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited