JsonValueRecordPartial class
Partial projection for JsonValueRecord.
All fields are nullable; intended for subset SELECTs.
Constructors
-
JsonValueRecordPartial({String? id, Object? objectValue, String? stringValue, Map<
String, dynamic> ? mapDynamic, Map<String, Object?> ? mapObject, List? listDynamic, List<Object?> ? listObject}) -
const
-
JsonValueRecordPartial.fromRow(Map<
String, Object?> row) -
Creates a partial from a database row map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- listDynamic → List?
-
final
-
listObject
→ List<
Object?> ? -
final
-
mapDynamic
→ Map<
String, dynamic> ? -
final
-
mapObject
→ Map<
String, Object?> ? -
final
- objectValue → Object?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringValue → String?
-
final
Methods
-
copyWith(
{Object? id = _copyWithSentinel, Object? objectValue = _copyWithSentinel, Object? stringValue = _copyWithSentinel, Object? mapDynamic = _copyWithSentinel, Object? mapObject = _copyWithSentinel, Object? listDynamic = _copyWithSentinel, Object? listObject = _copyWithSentinel}) → JsonValueRecordPartial -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toEntity(
) → $JsonValueRecord - Convert this partial into a full entity.
-
toMap(
) → Map< String, Object?> - Converts this partial to a map with column names as keys.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited